<?php declare(strict_types=1);
namespace GamesShop;

use GamesShop\Environment\EnvironmentHandler;
use GamesShop\Templates\TemplateEngine;
use League\Container\Container;
use Monolog\Logger;
use Throwable;
use Whoops\Handler\CallbackHandler;
use Whoops\Handler\HandlerInterface;
use Whoops\Handler\PrettyPageHandler;
use Whoops\Inspector\InspectorInterface;
use Whoops\Run;
use Whoops\RunInterface;

final class CrashHandler
{
    public function __construct(
        private readonly Container $container,
        private readonly EnvironmentHandler $env
    ) { }
    
    public function register() : void {
        error_reporting(0);
        
        $handler = $this->getHandler();
        $this->container->addShared(HandlerInterface::class, $handler);
        
        $whoops = new Run();
        $whoops->pushHandler($handler);
        $whoops->register();
    }
    
    private function getHandler(): HandlerInterface
    {
        if (!$this->env->isProduction()) {
            return new PrettyPageHandler();
        }
        
        return new CallbackHandler(
            function (Throwable $exception, InspectorInterface $inspector, RunInterface $run) {
                ContainerHandler::get(Logger::class)
                    ->emergency(
                        "Unexpected exception occurred: {$exception->getMessage()} at line {$exception->getLine()} in {$exception->getFile()}",
                    );
                
                http_response_code(500);
                echo ContainerHandler::get(TemplateEngine::class)
                    ->renderErrorPage(500);
            }
        );
    }
}