<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use Doctrine\ORM\EntityManager;
use Doctrine\ORM\Exception\ORMException;
use Doctrine\ORM\OptimisticLockException;
use GamesShop\ContainerHandler;
use GamesShop\Environment\EnvironmentHandler;
use GamesShop\Login\LoginHandler;
use GamesShop\Routing\Responses\TemplateResponse;
use GamesShop\Templates\TemplateEngine;
use Laminas\Diactoros\Response;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class LoginRoutes
{
    public function __construct(
        private readonly EntityManager $entityManager
    )
    {
    }

    public function login(ServerRequestInterface $request) {
        $discordEnv = ContainerHandler::get(EnvironmentHandler::class)->getDiscordEnvironment();

        return new TemplateResponse('login', [
            'discordUrl' => $discordEnv->loginUrl
        ]);
    }

    /**
     * @throws OptimisticLockException
     * @throws ORMException
     */
    public function loginCallback(ServerRequestInterface $request, array $args): ResponseInterface {
        if (array_key_exists('error', $request->getQueryParams())) {
            return new Response\RedirectResponse('/login');
        }

        $method = $args['method'];
        $loginHandler = ContainerHandler::get(LoginHandler::class);
        $loginProvider = $loginHandler->getLoginProvider($method);

        $user = $loginProvider->getUser($request);
        if ($user->getId() === null) {
            $this->entityManager->persist($user);
            $this->entityManager->flush();
        }

        $loginHandler->setCurrentUser($user);
        return new Response\RedirectResponse('/');
    }

    public function logout(ServerRequestInterface $request): ResponseInterface
    {
        $loginHandler = ContainerHandler::get(LoginHandler::class);
        $loginHandler->deleteSession();

        return new Response\RedirectResponse('/login');
    }

    public static function addRoutes(\League\Route\Router $router): void {
        $routes = ContainerHandler::get(LoginRoutes::class);

        $router->get('/login', $routes->login(...));
        $router->get('/login-callback/{method:word}', $routes->loginCallback(...));
        $router->get('/logout', $routes->logout(...));
    }
}