<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use GamesShop\ContainerHandler;
use GamesShop\Paths;
use Laminas\Diactoros\Response;
use Laminas\Diactoros\Uri;
use Mimey\MimeTypes;
use Psr\Http\Message\ResponseInterface;

final class ResourceRoute
{
    private const array RESOURCE_EXTENSIONS = [
        'js',
        'css',
        'ttf', 'woff', 'woff2',
        'gif', 'svg', 'png', 'jpg'
    ];

    public function isValid(Uri $uri): bool {
        $path = $uri->getPath();
        foreach (self::RESOURCE_EXTENSIONS as $extension) {
            if (!str_ends_with($path, $extension)) {
                continue;
            }

            return true;
        }
        return false;
    }

    public function getResponse(Uri $uri): ResponseInterface {
        $filePath = Paths::PUBLIC_PATH . $uri->getPath();

        if (!file_exists($filePath)) {
            $response = new Response(status: 404);
            $response->getBody()->write('File not found');

            return $response;
        }

        $mimey = ContainerHandler::get(MimeTypes::class);
        $response = new Response(
            headers: [
                'Content-Type' => $mimey->getMimeType(pathinfo($filePath, PATHINFO_EXTENSION)),
                'Cache-Control' => 'public, max-age=3600, must-revalidate',
            ]
        );
        $response->getBody()->write(file_get_contents($filePath));

        return $response;
    }
}