<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\SystemAttribute;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use Laminas\Diactoros\Response\RedirectResponse;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class SetupRoute
{
    public function __construct(
        private readonly EntityManager $entityManager,
        private readonly LoginHandler $loginHandler
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface {
        if (!$this->loginHandler->isLoggedIn()) {
            return new RedirectResponse('/login');
        }

        $repo = $this->entityManager->getRepository(SystemAttribute::class);

        $attribute = $repo->find('ADMIN_SETUP_COMPLETED');
        if ($attribute) {
            return new RedirectResponse('/');
        }

        $user = $this->loginHandler->getCurrentUser();
        $user->setPermission(UserPermission::ADMIN);

        $attribute = new SystemAttribute(
            'ADMIN_SETUP_COMPLETED',
            'true'
        );
        $this->entityManager->persist($attribute);
        $this->entityManager->flush();

        return new RedirectResponse('/');
    }

    public static function applyRoutes(\League\Route\Router $router) {
        $router->get('/setup-admin', self::class);
    }

}