<?php
declare(strict_types=1);

namespace GamesShop\Templates;

use Exception;
use GamesShop\Paths;

final class ResourceIndex
{
    private const string PATH = Paths::SOURCE_PATH . '/file-index.json';

    /**
     * @var ResourceEntry[]
     */
    private array $resources = [];

    public function __construct()
    {
        $fileContents = file_get_contents(self::PATH);
        $index = json_decode($fileContents, true);

        foreach ($index as $entryKey => $resource) {
            $js = $resource['js'];
            if (is_string($js)) {
                $js = [$js];
            }

            $css = $resource['css'];
            if (is_string($css)) {
                $css = [$css];
            }

            $this->resources[$entryKey] = new ResourceEntry(
                $js, $css
            );
        }
    }

    /**
     * @throws Exception
     */
    public function getResource(string $entry): ResourceEntry
    {
        if (!array_key_exists($entry, $this->resources)) {
            throw new Exception("Entry '$entry' not found");
        }

        return $this->resources[$entry];
    }
}