<?php
declare(strict_types=1);

use GamesShop\Entities\Account\User;
use GamesShop\Login\UserPermission;
use GamesShop\Templates\NavigationHeader;

$headers = [
    new NavigationHeader('My Keys', '/keys', UserPermission::PROVIDER),
    new NavigationHeader('Accounts', '/accounts', UserPermission::ADMIN)
];

/**  @var User|null $activeUser */
$currentPermission = $activeUser === null ? UserPermission::NONE : $activeUser->getPermission();

?>

<nav class="navbar navbar-expand-lg bg-body-tertiary main-navigation">
    <div class="container-fluid navigation-container">
        <a class="navbar-brand" href="/">Game Shop</a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbar-content" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbar-content">
            <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                <?php foreach ($headers as $header):
                    if (!$currentPermission->hasLevel($header->minimumPermission)) {
                        continue;
                    }
                    ?>


                    <li class="nav-link">
                        <a href="<?= $header->link ?>" class="nav-link"><?= $header->title ?></a>
                    </li>
                <?php endforeach; ?>
            </ul>

            <?= $this->insert('layout/accountDisplay'); ?>
        </div>
    </div>
    <div class="d-flex mode-switch me-3">
        <button title="Use dark mode" id="dark" class="btn btn-sm btn-default text-secondary">
            <i class="fa-regular fa-moon"></i>
        </button>
        <button title="Use light mode" id="light" class="btn btn-sm btn-default text-secondary">
            <i class="fa-regular fa-sun"></i>
        </button>
        <button title="Use system preferred mode" id="system" class="btn btn-sm btn-default text-secondary">
            <i class="fa-solid fa-display"></i>
        </button>
    </div>
</nav>